/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.converter;

import java.io.File;
import java.text.DecimalFormat;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

import kieker.analysis.model.analysisMetaModel.MIDependency;

/**
 * This converter can be used to convert an instance of <i>MIDependency</i> to
 * the size (in MiBByte) of the dependency, but of course <b>not</b> vice versa.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@FacesConverter(value = MIDependencyToSizeConverter.NAME)
public class MIDependencyToSizeConverter implements Converter {
	/**
	 * The name of this class used by the xhtml-files.
	 */
	public static final String NAME = "kieker.webgui.converter.MIDependencyToSizeConverter";
	/**
	 * The factor used to convert the size into MiBytes.
	 */
	private static final double FACTOR = 1.0 / 1024 / 1024; // NOCS (MagicNumberCheck)

	/**
	 * Creates a new instance of this class.
	 */
	public MIDependencyToSizeConverter() {
		/* No code necessary. */
	}

	/**
	 * Delivers always null.
	 * 
	 * @param fc
	 *            The FacesContext for the request being processed.
	 * @param uic
	 *            The component with which this model object value is
	 *            associated.
	 * @param string
	 *            The string to be converted.
	 * @return Always null.
	 */
	@Override
	public Object getAsObject(final FacesContext fc, final UIComponent uic, final String string) {
		return null;
	}

	/**
	 * Delivers a string-representation of the size of the given dependency.
	 * 
	 * @param fc
	 *            The FacesContext for the request being processed.
	 * @param uic
	 *            The component with which this model object value is
	 *            associated.
	 * @param o
	 *            The object to be converted.
	 * @return The size of the given object if it is a dependency and not null, an empty string otherwise.
	 */
	@Override
	public String getAsString(final FacesContext fc, final UIComponent uic, final Object o) {
		if (!(o instanceof MIDependency)) {
			return "";
		} else {
			final long size = new File(((MIDependency) o).getFilePath()).length();
			return new DecimalFormat("#.##").format(size * MIDependencyToSizeConverter.FACTOR).concat(" [MiByte]");
		}
	}
}
